@@ -14,8 +14,6 @@
 ( cd opt/kde/share/doc/HTML/it/kdat ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kdvi ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/kgeo ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kgeo ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kget ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kget ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kgpg ; rm -rf common )
@@ -56,6 +54,10 @@
 ( cd opt/kde/share/doc/HTML/it/kbounce ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kdearch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kdearch ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kdelirc/kcmlirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kdelirc/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kdelirc/irkick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kdelirc/irkick ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kbattleship ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kaboodle ; rm -rf common )
@@ -80,6 +82,8 @@
 ( cd opt/kde/share/doc/HTML/it/kfind ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kiten ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kiten ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kjots ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kjots ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmail ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kmail ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmoon ; rm -rf common )
@@ -92,8 +96,12 @@
 ( cd opt/kde/share/doc/HTML/it/ksysv ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ktron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ktron ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kttsd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kttsd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kuser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kuser ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kview ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kview ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kwin4 ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kwin4 ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/lskat ; rm -rf common )
@@ -118,8 +126,16 @@
 ( cd opt/kde/share/doc/HTML/it/konsole ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kpackage ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/khelpcenter/faq ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/khelpcenter/quickstart ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/khelpcenter/glossary ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/khelpcenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/khelpcenter/visualdict ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kshisen ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kshisen ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksirtet ; rm -rf common )
@@ -132,6 +148,8 @@
 ( cd opt/kde/share/doc/HTML/it/kturtle ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kverbos ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kwallet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kwallet ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kweather ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kxsldbg ; rm -rf common )
@@ -142,10 +160,10 @@
 ( cd opt/kde/share/doc/HTML/it/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kioslave ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/flashkard ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/flashkard ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kaddressbook ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf qpl-license.html )
@@ -168,6 +186,8 @@
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/6.png 6.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf 7.png )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/7.png 7.png )
+( cd opt/kde/share/doc/HTML/it/common ; rm -rf top-right-konqueror.png )
+( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf 8.png )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf 9.png )
@@ -198,6 +218,8 @@
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/it/common ; rm -rf bottom-left.png )
+( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf appheader.html )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf doctop1.png )
@@ -210,8 +232,12 @@
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
+( cd opt/kde/share/doc/HTML/it/common ; rm -rf top-middle.png )
+( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf fdl-license.html )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
+( cd opt/kde/share/doc/HTML/it/common ; rm -rf bottom-right.png )
+( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf doctop1a.png )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf 10.png )
@@ -228,6 +254,10 @@
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf header.html )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/header.html header.html )
+( cd opt/kde/share/doc/HTML/it/common ; rm -rf bottom-middle.png )
+( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
+( cd opt/kde/share/doc/HTML/it/common ; rm -rf top-left.png )
+( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/top-left.png top-left.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf gpl-license )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/gpl-license gpl-license )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde-localised.css.template )
@@ -238,12 +268,16 @@
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf artistic-license.html )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kdm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/smb ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/spellchecking ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/bell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/keys ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/powerctrl ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kalarmd ; rm -rf common )
@@ -260,6 +294,12 @@
 ( cd opt/kde/share/doc/HTML/it/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/fonts ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/icons ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/khtml ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/filemanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/mouse ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/proxy ; rm -rf common )
@@ -290,22 +330,56 @@
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmcss ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/laptop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmnotify ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmsmserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/windowmanagement ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kwindecoration ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/useragent ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlowbatcrit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlowbatwarn ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/keyboard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/crashes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/babel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/kuick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/kuick ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/webarchiver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/webarchiver ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/domtreeviewer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/smbmounter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/smbmounter ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/imgallery ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/imgallery ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/khtmlsettings ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/khtmlsettings ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/validators ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/fsview ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/fsview ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/uachanger ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/mediaplayer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/dirfilter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konq-plugins/dirfilter ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kbabel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kbabel ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kamera ; rm -rf common )
@@ -316,6 +390,8 @@
 ( cd opt/kde/share/doc/HTML/it/kbruch ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/keduca ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/keduca ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kgamma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kgamma ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kdevelop ; rm -rf common )
@@ -366,8 +442,6 @@
 ( cd opt/kde/share/doc/HTML/it/kblackbox ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcharselect ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/quanta ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/quanta ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kuickshow ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kde_app_devel ; rm -rf common )
@@ -376,6 +450,8 @@
 ( cd opt/kde/share/doc/HTML/it/kommander ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kiconedit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kmahjongg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kmahjongg ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/klettres ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/klettres ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kfouleggs ; rm -rf common )
@@ -384,16 +460,18 @@
 ( cd opt/kde/share/doc/HTML/it/kghostview ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/klickety ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/klickety ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kfilereplace ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kfilereplace ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kleopatra ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kleopatra ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kenolaba ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/kgpgcertmanager ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kworldclock ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/KRegExpEditor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksokoban ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ksokoban ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kteatime ; rm -rf common )
@@ -418,6 +496,8 @@
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/xserver ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/samba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/sound ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/partitions ; rm -rf common )
@@ -428,6 +508,8 @@
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/pcmcia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/opengl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/processor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/ioports ; rm -rf common )
